#!python

import asyncio
import sys
import subprocess
import sshtunnel

from mt import net, logg, tfc


def execute(argv):
    res = subprocess.run(argv[1:], shell=False, check=False)
    sys.exit(res.returncode)


async def main():
    argv = sys.argv
    logg.logger.setLevel(logg.INFO)

    if len(argv) < 2:
        print("Opens localhost:5443 as nexus https and runs a command.")
        print("Syntax: {} cmd arg1 arg2 ...".format(argv[0]))
        sys.exit(0)

    if net.is_port_open("localhost", 5443, timeout=0.1):
        execute(argv)

    l_endpoints = [
        ("192.168.110.4", 443),
        ("nexus.winnow.tech", 443),
    ]

    for host, port in l_endpoints:
        if not net.is_port_open(host, port):
            continue

        server = await net.port_forwarder_actx(
            ":5443", [f"{host}:{port}"], logger=logg.logger
        )
        async with server:
            process = await asyncio.create_subprocess_exec(*argv[1:])
            returncode = await process.wait()
            sys.exit(returncode)

    u, p = tfc.make_debug_list()

    if u[4] != p[5]:
        logg.logger.error("Unable to connect to nexus.")
        sys.exit(1)

    with sshtunnel.open_tunnel(
        ("clujdc.edge.winnowsolutions.com", 22222),
        ssh_username=u,
        ssh_password=p,
        remote_bind_address=("192.168.110.4", 443),
        local_bind_address=("0.0.0.0", 5443),
    ) as tun:
        execute(argv)


if __name__ == "__main__":
    asyncio.run(main())
